@@ -675,29 +675,6 @@ class KecClient(AbstractClient):
                 raise KsyunSDKException(e.message, e.message)
 
 
-    def RenameDedicatedHost(self, request):
-        """修改专属宿主机名称
-        :param request: Request instance for RenameDedicatedHost.
-        :type request: :class:`ksyun.client.kec.v20160304.models.RenameDedicatedHostRequest`
-        """
-        try:
-            params = request._serialize()
-            body = self.call_judge("RenameDedicatedHost", params, "application/x-www-form-urlencoded")
-            response = json.loads(body)
-            if "Error" not in response:
-                return body
-            else:
-                code = response["Error"]["Code"]
-                message = response["Error"]["Message"]
-                req_id = response["RequestId"]
-                raise KsyunSDKException(code, message, req_id)
-        except Exception as e:
-            if isinstance(e, KsyunSDKException):
-                raise
-            else:
-                raise KsyunSDKException(e.message, e.message)
-
-
     def DescribeDedicatedHosts(self, request):
         """描述专属宿主机信息
         :param request: Request instance for DescribeDedicatedHosts.
@@ -2147,6 +2124,29 @@ class KecClient(AbstractClient):
                 raise KsyunSDKException(e.message, e.message)
 
 
+    def CopySnapshot(self, request):
+        """本地盘快照跨region复制
+        :param request: Request instance for CopySnapshot.
+        :type request: :class:`ksyun.client.kec.v20160304.models.CopySnapshotRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("CopySnapshot", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
+
+
     def PreMigrateInstance(self, request):
         """创建预迁移
         :param request: Request instance for PreMigrateInstance.
@@ -2193,29 +2193,6 @@ class KecClient(AbstractClient):
                 raise KsyunSDKException(e.message, e.message)
 
 
-    def DescribeMinFlavorCount(self, request):
-        """DescribeMinFlavorCount
-        :param request: Request instance for DescribeMinFlavorCount.
-        :type request: :class:`ksyun.client.kec.v20160304.models.DescribeMinFlavorCountRequest`
-        """
-        try:
-            params = request._serialize()
-            body = self.call_judge("DescribeMinFlavorCount", params, "application/json")
-            response = json.loads(body)
-            if "Error" not in response:
-                return body
-            else:
-                code = response["Error"]["Code"]
-                message = response["Error"]["Message"]
-                req_id = response["RequestId"]
-                raise KsyunSDKException(code, message, req_id)
-        except Exception as e:
-            if isinstance(e, KsyunSDKException):
-                raise
-            else:
-                raise KsyunSDKException(e.message, e.message)
-
-
     def GetVNCAddress(self, request):
         """OpenAPI获取浏览器可用的VNC地址
         :param request: Request instance for GetVNCAddress.
